Crate maili_interop

maili-interop

CI maili-interop crate MIT License Apache License Book

Interop types for Optimism.

Structs

ChainRootInfo
Chain Root Info
DerivedIdPair
A derived ID pair is a pair of block IDs, where Derived (L2) is derived from DerivedFrom (L1).
EnrichedExecutingMessage
A wrapper type for ExecutingMessage containing the chain ID of the chain that the message was executed on.
ExecutingMessage
@notice Emitted when a cross chain message is being executed. @param msgHash Hash of message payload being executed. @param id Encoded Identifier of the message. Event with signature ExecutingMessage(bytes32,(address,uint256,uint256,uint256,uint256)) and selector 0x5c37832d2e8d10e346e55ad62071a6a2f9fa5130614ef2ec6617555c6f467ba7.
MessageIdentifier
@notice The struct for a pointer to a message payload in a remote (or local) chain.
MessagePayload
A MessagePayload is the raw payload of an initiating message.
OutputRootWithChain
A wrapper around an output root hash with the chain ID it belongs to.
SuperRoot
The SuperRoot is the snapshot of the superchain at a given timestamp.
SuperRootResponse
The super root response type.

Enums

SafetyLevel
The safety level of a message.
SuperRootError
An error type for the SuperRoot struct’s serialization and deserialization.

Constants

CROSS_L2_INBOX_ADDRESS
The address of the L2 cross chain inbox predeploy proxy.
MESSAGE_EXPIRY_WINDOW
The expiry window for relaying an initiating message (in seconds). https://specs.optimism.io/interop/messaging.html#message-expiry-invariant
SUPER_ROOT_VERSION
The current version of the super root encoding format.

Functions

extract_executing_messages
Extracts all ExecutingMessage logs from a list of receipts.

Type Aliases

SuperRootResult
A Result alias for the SuperRootError type.