pub struct EnrichedExecutingMessage {
pub inner: ExecutingMessage,
pub executing_chain_id: u64,
}Expand description
A wrapper type for ExecutingMessage containing the chain ID of the chain that the message was executed on.
Fields
inner: ExecutingMessageThe inner ExecutingMessage.
executing_chain_id: u64The chain ID of the chain that the message was executed on.
Implementations
Sourceimpl EnrichedExecutingMessage
impl EnrichedExecutingMessage
Sourcepub const fn new(inner: ExecutingMessage, executing_chain_id: u64) -> Self
pub const fn new(inner: ExecutingMessage, executing_chain_id: u64) -> Self
Create a new EnrichedExecutingMessage from an ExecutingMessage and a chain ID.