pub struct ExecutingMessage {
pub msgHash: FixedBytes<32>,
pub id: <MessageIdentifier as SolType>::RustType,
}Expand description
@notice Emitted when a cross chain message is being executed.
@param msgHash Hash of message payload being executed.
@param id Encoded Identifier of the message.
Event with signature ExecutingMessage(bytes32,(address,uint256,uint256,uint256,uint256)) and selector 0x5c37832d2e8d10e346e55ad62071a6a2f9fa5130614ef2ec6617555c6f467ba7.
event ExecutingMessage(bytes32 indexed msgHash, MessageIdentifier id);Fields
msgHash: FixedBytes<32>id: <MessageIdentifier as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for ExecutingMessage
impl Clone for ExecutingMessage
Sourcefn clone(&self) -> ExecutingMessage
fn clone(&self) -> ExecutingMessage
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecutingMessage
impl Debug for ExecutingMessage
Sourceimpl Default for ExecutingMessage
impl Default for ExecutingMessage
Sourcefn default() -> ExecutingMessage
fn default() -> ExecutingMessage
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ExecutingMessage
impl<'de> Deserialize<'de> for ExecutingMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&ExecutingMessage> for LogData
impl From<&ExecutingMessage> for LogData
Sourcefn from(this: &ExecutingMessage) -> LogData
fn from(this: &ExecutingMessage) -> LogData
Converts to this type from the input type.
Sourceimpl IntoLogData for ExecutingMessage
impl IntoLogData for ExecutingMessage
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
Convert into a
LogData object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
Consume and convert into a
LogData object.Sourceimpl PartialEq for ExecutingMessage
impl PartialEq for ExecutingMessage
Sourceimpl Serialize for ExecutingMessage
impl Serialize for ExecutingMessage
Sourceimpl SolEvent for ExecutingMessage
impl SolEvent for ExecutingMessage
Sourceconst SIGNATURE: &'static str = "ExecutingMessage(bytes32,(address,uint256,uint256,uint256,uint256))"
const SIGNATURE: &'static str = "ExecutingMessage(bytes32,(address,uint256,uint256,uint256,uint256))"
The event’s ABI signature. Read more
Sourceconst SIGNATURE_HASH: B256
const SIGNATURE_HASH: B256
The event’s ABI signature hash, or selector:
keccak256(SIGNATURE) Read moreSourcetype DataTuple<'a> = (MessageIdentifier,)
type DataTuple<'a> = (MessageIdentifier,)
The underlying tuple type which represents this event’s non-indexed
parameters. These parameters are ABI encoded and included in the log
body. Read more
Sourcetype DataToken<'a> = <<ExecutingMessage as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
type DataToken<'a> = <<ExecutingMessage as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
The
TokenSeq type corresponding to the tuple.Sourcetype TopicList = (FixedBytes<32>, FixedBytes<32>)
type TopicList = (FixedBytes<32>, FixedBytes<32>)
The underlying tuple type which represents this event’s topics. Read more
Sourcefn new(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Self
fn new( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Self
Convert decoded rust data to the event type. Read more
Sourcefn check_signature(
topics: &<Self::TopicList as SolType>::RustType,
) -> Result<()>
fn check_signature( topics: &<Self::TopicList as SolType>::RustType, ) -> Result<()>
Check that the event’s signature matches the given topics.
Sourcefn tokenize_body(&self) -> Self::DataToken<'_>
fn tokenize_body(&self) -> Self::DataToken<'_>
Tokenize the event’s non-indexed parameters.
Sourcefn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
Encode the topics of this event into the given buffer. Read more
Sourcefn new_checked(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Result<Self, Error>
fn new_checked( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Result<Self, Error>
Convert decoded rust data to the event type. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the ABI-encoded dynamic data in bytes.
Sourcefn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data_to(&self, out: &mut Vec<u8>)
ABI-encode the dynamic data of this event into the given buffer.
Sourcefn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
Encode the topics of this event into a fixed-size array. Read more
Sourcefn encode_log_data(&self) -> LogData
fn encode_log_data(&self) -> LogData
Encode this event to a
LogData.Sourcefn encode_log(log: &Log<Self>) -> Log
fn encode_log(log: &Log<Self>) -> Log
Sourcefn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>
fn decode_topics<I, D>( topics: I, ) -> Result<<Self::TopicList as SolType>::RustType, Error>
Decode the topics of this event from the given data.
Sourcefn abi_decode_data<'a>(
data: &'a [u8],
validate: bool,
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data<'a>( data: &'a [u8], validate: bool, ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer.
Sourcefn decode_raw_log<I, D>(
topics: I,
data: &[u8],
validate: bool,
) -> Result<Self, Error>
fn decode_raw_log<I, D>( topics: I, data: &[u8], validate: bool, ) -> Result<Self, Error>
Decode the event from the given log info.
impl Eq for ExecutingMessage
impl StructuralPartialEq for ExecutingMessage