pub struct MessageGraph<'a, P> { /* private fields */ }Expand description
The message graph represents a set of blocks at a given timestamp and the interop dependencies between them.
This structure is used to determine whether or not any interop messages are invalid within the set of blocks within the graph. An “invalid message” is one that was relayed from one chain to another, but the original MessageIdentifier is not present within the graph or from a dependency referenced via the InteropProvider (or otherwise is invalid, such as being older than the message expiry window).
Message validity rules: https://specs.optimism.io/interop/messaging.html#invalid-messages
Implementations
Sourceimpl<'a, P> MessageGraph<'a, P>where
P: InteropProvider,
impl<'a, P> MessageGraph<'a, P>where
P: InteropProvider,
Sourcepub async fn derive(
blocks: &[(u64, Sealed<Header>)],
provider: &'a P,
rollup_configs: &'a HashMap<u64, RollupConfig>,
) -> Result<MessageGraph<'a, P>, MessageGraphError<<P as InteropProvider>::Error>>
pub async fn derive( blocks: &[(u64, Sealed<Header>)], provider: &'a P, rollup_configs: &'a HashMap<u64, RollupConfig>, ) -> Result<MessageGraph<'a, P>, MessageGraphError<<P as InteropProvider>::Error>>
Derives the edges from the blocks within the graph by scanning all receipts within the blocks and searching for ExecutingMessages.
Sourcepub async fn resolve(
self,
) -> Result<(), MessageGraphError<<P as InteropProvider>::Error>>
pub async fn resolve( self, ) -> Result<(), MessageGraphError<<P as InteropProvider>::Error>>
Checks the validity of all messages within the graph.