Structs
- Chain
Root Info - Chain Root Info
- Derived
IdPair - A derived ID pair is a pair of block IDs, where Derived (L2) is derived from DerivedFrom (L1).
- Enriched
Executing Message - A wrapper type for ExecutingMessage containing the chain ID of the chain that the message was executed on.
- Executing
Message - @notice Emitted when a cross chain message is being executed.
@param msgHash Hash of message payload being executed.
@param id Encoded Identifier of the message.
Event with signature
ExecutingMessage(bytes32,(address,uint256,uint256,uint256,uint256))and selector0x5c37832d2e8d10e346e55ad62071a6a2f9fa5130614ef2ec6617555c6f467ba7. - Message
Identifier - @notice The struct for a pointer to a message payload in a remote (or local) chain.
- Message
Payload - A MessagePayload is the raw payload of an initiating message.
- Output
Root With Chain - A wrapper around an output root hash with the chain ID it belongs to.
- Super
Root - The SuperRoot is the snapshot of the superchain at a given timestamp.
- Super
Root Response - The super root response type.
Enums
- Safety
Level - The safety level of a message.
- Super
Root Error - An error type for the SuperRoot struct’s serialization and deserialization.
Constants
- CROSS_
L2_ INBOX_ ADDRESS - The address of the L2 cross chain inbox predeploy proxy.
- MESSAGE_
EXPIRY_ WINDOW - The expiry window for relaying an initiating message (in seconds). https://specs.optimism.io/interop/messaging.html#message-expiry-invariant
- SUPER_
ROOT_ VERSION - The current version of the super root encoding format.
Functions
- extract_
executing_ messages - Extracts all ExecutingMessage logs from a list of receipts.
Type Aliases
- Super
Root Result - A Result alias for the SuperRootError type.