pub struct ChainRootInfo {
pub chain_id: u64,
pub canonical: FixedBytes<32>,
pub pending: Bytes,
}Expand description
Chain Root Info
Fields
chain_id: u64The chain ID.
canonical: FixedBytes<32>The canonical output root of the latest canonical block at a particular timestamp.
pending: BytesThe pending output root.
This is the output root preimage for the latest block at a particular timestamp prior to
validation of executing messages. If the original block was valid, this will be the
preimage of the output root from the canonical array. If it was invalid, it will be
the output root preimage from the optimistic block deposited transaction added to the
deposit-only block.