Struct SuperRoot

pub struct SuperRoot {
    pub timestamp: u64,
    pub output_roots: Vec<OutputRootWithChain>,
}
The SuperRoot is the snapshot of the superchain at a given timestamp.

Fields

timestamp: u64

The timestamp of the superchain snapshot, in seconds.

output_roots: Vec<OutputRootWithChain>

The chain IDs and output root commitments of all chains within the dependency set.

Implementations

Source

impl SuperRoot

pub fn new(timestamp: u64, output_roots: Vec<OutputRootWithChain>) -> SuperRoot

Create a new SuperRoot with the given timestamp and output roots.

pub fn decode(buf: &mut &[u8]) -> Result<SuperRoot, SuperRootError>

Decodes a SuperRoot from the given buffer.

pub fn encode(&self, out: &mut dyn BufMut)

Encode the SuperRoot into the given buffer.

pub fn encoded_length(&self) -> usize

Returns the encoded length of the SuperRoot.

pub fn hash(&self) -> FixedBytes<32>

Hashes the encoded SuperRoot using keccak256.