pub struct SuperRootResponse {
pub timestamp: u64,
pub super_root: B256,
pub chains: Vec<ChainRootInfo>,
}Expand description
The super root response type.
Fields
timestamp: u64The timestamp of the super root.
super_root: B256The super root hash.
chains: Vec<ChainRootInfo>The chain root info for each chain in the dependency set. It represents the state of the chain at or before the timestamp.